Author: tfmorris
Date: 2008-01-06 23:00:23-0800
New Revision: 14027

Modified:
   trunk/src/model/src/org/argouml/model/CoreFactory.java

Log:
Update Javadoc for buildAttribute*.  No functional changes.

Modified: trunk/src/model/src/org/argouml/model/CoreFactory.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/model/src/org/argouml/model/CoreFactory.java?view=diff&rev=14027&p1=trunk/src/model/src/org/argouml/model/CoreFactory.java&p2=trunk/src/model/src/org/argouml/model/CoreFactory.java&r1=14026&r2=14027
==============================================================================
--- trunk/src/model/src/org/argouml/model/CoreFactory.java      (original)
+++ trunk/src/model/src/org/argouml/model/CoreFactory.java      2008-01-06 
23:00:23-0800
@@ -383,26 +383,26 @@
     Object buildAttribute2(Object type);
     
     /**
-     * Builds an attribute owned by some classifier cls. 
+     * Builds an attribute owned by a classifier. 
      *
-     * @param handle the given classifier
+     * @param classifier the classifier to own the new attribute
      * @param model the enclosing model
      * @param type the type
-     * @return the newly build attribute
+     * @return the newly built attribute
      * @deprecated for 0.25.2 by tfmorris - use the side effect free version
      * [EMAIL PROTECTED] #buildAttribute2(Object, Object)}
      */
     @Deprecated
-    Object buildAttribute(Object handle, Object model, Object type);
+    Object buildAttribute(Object classifier, Object model, Object type);
 
     /**
      * Builds an attribute of the given type. <p>
      *
-     * @param handle the given classifier
+     * @param classifier the classifier which will own the new attribute
      * @param type the type
      * @return the newly built attribute
      */
-    Object buildAttribute2(Object handle, Object type);
+    Object buildAttribute2(Object classifier, Object type);
     
     /**
      * Builds a default implementation for a class. The class is not owned by

---------------------------------------------------------------------
@@ -383,26 +383,26 @@
 
     /**
-     * Builds an attribute of the given type. <p>
+     * Builds an attribute of the given type owned by a classifier.
      *
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]

Reply via email to